package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.RegisterTeacher;

/**
 * 注册-老师Service接口
 * 
 * @author ruoyi
 * @date 2023-05-25
 */
public interface IRegisterTeacherService 
{
    /**
     * 查询注册-老师
     * 
     * @param id 注册-老师主键
     * @return 注册-老师
     */
    public RegisterTeacher selectRegisterTeacherById(Long id);

    /**
     * 查询注册-老师列表
     * 
     * @param registerTeacher 注册-老师
     * @return 注册-老师集合
     */
    public List<RegisterTeacher> selectRegisterTeacherList(RegisterTeacher registerTeacher);

    /**
     * 新增注册-老师
     * 
     * @param registerTeacher 注册-老师
     * @return 结果
     */
    public AjaxResult insertRegisterTeacher(RegisterTeacher registerTeacher);

    /**
     * 修改注册-老师
     * 
     * @param registerTeacher 注册-老师
     * @return 结果
     */
    public int updateRegisterTeacher(RegisterTeacher registerTeacher);

    /**
     * 批量删除注册-老师
     * 
     * @param ids 需要删除的注册-老师主键集合
     * @return 结果
     */
    public int deleteRegisterTeacherByIds(Long[] ids);

    /**
     * 删除注册-老师信息
     * 
     * @param id 注册-老师主键
     * @return 结果
     */
    public int deleteRegisterTeacherById(Long id);
}
